@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.7.9"
+    version = "1.8.0"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -107,7 +107,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         event = notification.event
         group = event.group
         project = group.project
-        self._post(event, project)
+        self._post(group, project, event)
 
     def notify_about_activity(self, activity):
         project = activity.project
@@ -115,23 +115,23 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         self._post(group, project)
 
-    def _post(self, group, project):
+    def _post(self, group, project, event=''):
         custom_keyword = self.get_option("custom_keyword", project)
         # # 告警次数阀值
         number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 10
         phones = self.get_option("phones", project)
         #
-        issue_link = group.group.get_absolute_url(params={"referrer": "dingtalknotify"})
+        issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
         issue_link = issue_link.replace('https', 'http')
 
 
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
-        payload = f"{payload} > 出现次数: {group.group.times_seen} \n\n"
+        payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
         # payload = f"{payload} > 查看详情: <font color=blue>[{group.title if 'unknown' not in group.title else 'unknown'}]({issue_link})</font> \n\n"
         # payload = f"{payload} > 具体报错: {group.message} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
-        payload = f"{payload} > Hi: {group.__dict__} \n\n"
+        payload = f"{payload} > Hi: {event.__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
         # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
         # payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__} \n\n"
@@ -160,11 +160,11 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         # 获取预设的阀值
         counts = self.get_option("warning_counts", project)
-        if int(group.group.status) == 0:
+        if int(group.status) == 0:
             data_1 = {
                 "msgtype": "markdown",
                 "markdown": {
-                    "title": group.group.title,
+                    "title": group.title,
                     "text": payload + '\n\n' + '@' + '@'.join(phone)
                 },
                 "at": {
